@@ -24,6 +24,8 @@ from colored import Style,Fore
 import json,sys,math,re,calendar
 import plotext as plt
 import pint_pandas
+import radboy.DB.ExerciseTracker as ET
+import zipfile
 
 class HealthLogUi:
 	def edit_hlid(self):
@@ -155,8 +157,17 @@ class HealthLogUi:
 				print(fields,"empty!")
 				return
 			data=FormBuilder(data=fields)
+			if data is None:
+				return
 			if 'LongActingInsulinName' in useColumns or 'ShortActingInsulinName' in useColumns:
 				def searchNames(code):
+					if code is None:
+						if 'LongActingInsulinName' in useColumns:
+							return 'Long Acting Insuline Unspecificied - see comments'
+						elif 'ShortActingInsulinName' in useColumns:
+							return 'Short Acting Insulin Unspecificied - see comments'
+						else:
+							return 'see comments'
 					with Session(ENGINE) as session:
 						query=session.query(Entry)
 						filters=[
@@ -171,6 +182,7 @@ class HealthLogUi:
 							print(msg)
 							return code
 						htext=[]
+						print(f"{Fore.orange_red_1}Getting Results({Fore.light_green}{ct}{Fore.orange_red_1}) for Display!{Style.reset}")
 						for num,i in enumerate(results):
 							msg=f"{Fore.light_cyan}{num}/{Fore.light_magenta}{num+1} of {Fore.light_red}{ct} {Fore.medium_violet_red} -> {i.seeShort()}"
 							htext.append(msg)
@@ -256,28 +268,106 @@ class HealthLogUi:
 			print(e)
 
 	def export_log(self):
+		try:
+			with BooleanAnswers.IllegalCharsManifest.open("w") as output:
+				output.write("Below is a list of Characters replaced with a non-illegal equivalents.\n")
+				output.write("Replacement in Text = Character\n")
+		except Exception as e:
+			print(e)
+		useDateRange=Prompt.__init2__(None,func=FormBuilderMkText,ptext="use a date range?",helpText="yes or no",data="boolean")
+		if useDateRange is None:
+			return
+		elif useDateRange in ['d',]:
+			useDateRange=True
 		output=Path("HealthLogAll.xlsx")
 		with Session(ENGINE) as session:
 			query=session.query(HealthLog)
 			query=orderQuery(query,HealthLog.DTOE)
+			if useDateRange:
+				default_sd=datetime.now()-timedelta(days=30)
+				start_date=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"Start Date(default = {default_sd}):",helpText="start date",data="datetime")
+				if start_date is None:
+					return
+				elif start_date in ['d',]:
+					start_date=default_sd
+
+				default_ed=datetime.now()
+				end_date=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"End Date(default = {default_ed}):",helpText="end date",data="datetime")
+				if end_date is None:
+					return
+				elif end_date in ['d',]:
+					end_date=default_ed
+
+				query=query.filter(and_(HealthLog.DTOE>=start_date,HealthLog.DTOE<=end_date))
+
 			df=pd.read_sql(query.statement,session.bind)
+			
+			#str.replace(lambda x:x,lambda x:strip_colors(x))
+			#df=df.apply(remove_illegals)
+			for i in df:
+				df[i]=df[i].apply(lambda x:remove_illegals(strip_colors(x)) if isinstance(x,str) else x)
+				#df[i]=df[i].apply(remove_illegals)
 			df.to_excel(output,index=False)
+			with zipfile.ZipFile(BooleanAnswers.HealthLogZip,"w") as oz:
+				oz.write(output)
+				oz.write(BooleanAnswers.IllegalCharsManifest)
 			print(output.absolute())
+			print(BooleanAnswers.IllegalCharsManifest.absolute())
+			print(f"{Fore.orange_red_1}The Below file only contains the above files!{Style.reset}")
+			print(BooleanAnswers.HealthLogZip.absolute())
 
 	def export_log_field(self,fields=[],not_none=[]):
+		try:
+			with BooleanAnswers.IllegalCharsManifest.open("w") as output:
+				output.write("Below is a list of Characters replaced with a non-illegal equivalents.\n")
+				output.write("Replacement in Text = Character\n")
+		except Exception as e:
+			print(e)
+		useDateRange=Prompt.__init2__(None,func=FormBuilderMkText,ptext="use a date range?",helpText="yes or no",data="boolean")
+		if useDateRange is None:
+			return
+		elif useDateRange in ['d',]:
+			useDateRange=True
+
 		if 'DTOE' not in fields:
 			fields.append('DTOE')
 		if 'Comments' not in fields:
 			fields.append('Comments')
-		output=Path(f"HealthLog-{'_'.join(fields)}.xlsx")
+		output=Path(f"HealthLog-fields.xlsx")
 		not_none=[i for i in HealthLog.__table__.columns if str(i.name) in not_none]
 		with Session(ENGINE) as session:
 			query=session.query(HealthLog).filter(or_(*[i!=None for i in not_none]))
 			query=orderQuery(query,HealthLog.DTOE)
+			if useDateRange:
+				default_sd=datetime.now()-timedelta(days=30)
+				start_date=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"Start Date(default = {default_sd}):",helpText="start date",data="datetime")
+				if start_date is None:
+					return
+				elif start_date in ['d',]:
+					start_date=default_sd
+
+				default_ed=datetime.now()
+				end_date=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"End Date(default = {default_ed}):",helpText="end date",data="datetime")
+				if end_date is None:
+					return
+				elif end_date in ['d',]:
+					end_date=default_ed
+
+				query=query.filter(and_(HealthLog.DTOE>=start_date,HealthLog.DTOE<=end_date))
+			query=orderQuery(query,HealthLog.DTOE)
 			df=pd.read_sql(query.statement,session.bind)
+
 			df=df[fields]
+			for i in df:
+				df[i]=df[i].apply(lambda x:remove_illegals(strip_colors(x)) if isinstance(x,str) else x)
 			df.to_excel(output,index=False)
+			with zipfile.ZipFile(BooleanAnswers.HealthLogZip,"w") as oz:
+				oz.write(output)
+				oz.write(BooleanAnswers.IllegalCharsManifest)
 			print(output.absolute())
+			print(BooleanAnswers.IllegalCharsManifest.absolute())
+			print(f"{Fore.orange_red_1}The Below file only contains the above files!{Style.reset}")
+			print(BooleanAnswers.HealthLogZip.absolute())
 
 
 	def fixtable(self):
@@ -590,6 +680,11 @@ class HealthLogUi:
 			'desc':'list blood sugars',
 			'exec':lambda self=self:self.showAllField(fields=['BloodSugar','BloodSugarUnitName'],not_none=['BloodSugar',])
 			},
+			'et':{
+			'cmds':['et','exercise tracker','exrcse trckr',],
+			'desc':'exercise tracker short cut',
+			'exec':ET.ExerciseTracker
+			},
 			'lsdrug':{
 			'cmds':['ls drug','ls dg','list drug','lsdrug','lsdrg'],
 			'desc':'list drug data',
@@ -646,6 +741,11 @@ class HealthLogUi:
 			'desc':'list height',
 			'exec':lambda self=self:self.showAllField(fields=['Height','HeightUnitName'],not_none=['Height',])
 			},
+			'ls welsh':{
+			'cmds':['ls welsh','list welsh'],
+			'desc':'list data for diabete\'s dr.',
+			'exec':lambda self=self:self.showAllField(fields=['BloodSugar','BloodSugarUnitName','LongActingInsulinName','LongActingInsulinTaken','LongActingInsulinUnitName','ShortActingInsulinName','ShortActingInsulinTaken','ShortActingInsulinUnitName','HeartRate','HeartRateUnitName','DrugConsumed','DrugQtyConsumed','DrugQtyConsumedUnitName','CarboHydrateIntake','CarboHydrateIntakeUnitName','Comments',],not_none=['Comments',])
+			},
 			'ls consumed':{
 				'cmds':['lsfd','ls fd','ls food','lfd','ls fuel','ls fl','lfl'],
 				'desc':'list food',
@@ -704,8 +804,18 @@ class HealthLogUi:
 			'desc':'export height',
 			'exec':lambda self=self:self.export_log_field(fields=['Height','HeightUnitName'],not_none=['Height',])
 			},
+			'xpt cmts':{
+			'cmds':['xptcmts','xpt cmts','xpt cmt',],
+			'desc':'export height',
+			'exec':lambda self=self:self.export_log_field(fields=['Comments',],not_none=['Comments',])
+			},
+			'xpt welsh':{
+			'cmds':['export welsh','xpt welsh'],
+			'desc':'export data for diabete\'s dr.',
+			'exec':lambda self=self:self.export_log_field(fields=['BloodSugar','BloodSugarUnitName','LongActingInsulinName','LongActingInsulinTaken','LongActingInsulinUnitName','ShortActingInsulinName','ShortActingInsulinTaken','ShortActingInsulinUnitName','HeartRate','HeartRateUnitName','DrugConsumed','DrugQtyConsumed','DrugQtyConsumedUnitName','CarboHydrateIntake','CarboHydrateIntakeUnitName','Comments',],not_none=['Comments',])
+			},
 			'xpt consumed':{
-				'cmds':['xptfd','xpt fd','xpt food','lfd','xpt fuel','xpt fl','xlfl'],
+				'cmds':['xptfd','xpt fd','xpt food','xpt-fd','xpt fuel','xpt fl','xlfl'],
 				'desc':'export food',
 				'exec':lambda self=self:self.export_log_field(
 					fields=["EntryBarcode",
